==> haskell-hjsmin-0.2.1-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hjsmin
version:              0.2.1
visibility:           public
id:                   hjsmin-0.2.1-K4qCRcx0Nus9QAbNlDmnCn
key:                  hjsmin-0.2.1-K4qCRcx0Nus9QAbNlDmnCn
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  3e3e488032f5482fa8f549cd121db239
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hjsmin
hs-libraries:         HShjsmin-0.2.1-K4qCRcx0Nus9QAbNlDmnCn
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    language-javascript-0.7.1.0-1j9MKaQlgsVE2dPnzHnf4L text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.2.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hjsmin
version:              0.2.1
visibility:           public
id:                   hjsmin-0.2.1-9StHo7RAD0R6QWjmv2zlDk
key:                  hjsmin-0.2.1-9StHo7RAD0R6QWjmv2zlDk
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  a3a7ce8a80fefdb650e5a255be2fc879
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hjsmin
hs-libraries:         HShjsmin-0.2.1-9StHo7RAD0R6QWjmv2zlDk
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    language-javascript-0.7.1.0-52Ic1MF9RlwJiNEYIycp1m text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
